:mod:`art.attacks.inference.membership_inference`
=================================================
.. automodule:: art.attacks.inference.membership_inference

Membership Inference Black-Box
------------------------------
.. autoclass:: MembershipInferenceBlackBox
   :members:
   :special-members:

Membership Inference Black-Box Rule-Based
-----------------------------------------
.. autoclass:: MembershipInferenceBlackBoxRuleBased
   :members:
   :special-members:

Membership Inference Label-Only - Decision Boundary
---------------------------------------------------
.. autoclass:: LabelOnlyDecisionBoundary
   :members:
   :special-members:

Membership Inference Label-Only - Gap Attack
--------------------------------------------
.. autoclass:: LabelOnlyGapAttack
   :members:
   :special-members:

Shadow Models
-------------
.. autoclass:: ShadowModels
   :members:
   :special-members:
